Learn R Programming

hydroState (version 0.2.0.0)

get.residuals: Get pseudo residuals

Description

The pseudo residuals were derived from the conditional probabilities of the observations. At each time-step, the pseudo residual is the probability of an observation occurring given the prior observations and latter observations.

Usage

get.residuals(model)

Value

Data frame of residuals for each time-step

Arguments

model

fitted hydroState model object.

Details

get.residuals

get.residuals retrieves residuals from the fitted model and exports them as a data frame.

Examples

Run this code
# Load fitted model
data(model.annual.fitted.221201)

## Get residuals in a dataframe
get.residuals(model = model.annual.fitted.221201)


Run the code above in your browser using DataLab