The pseudo residuals were derived from the conditional probabilities of the observations. At each time-step, the pseudo residual is the probability of an observation occurring given the prior observations and latter observations.
Usage
get.residuals(model)
Value
Data frame of residuals for each time-step
Arguments
model
fitted hydroState model object.
Details
get.residuals
get.residuals retrieves residuals from the fitted model and exports them as a data frame.